@@ -1,6 +1,4 @@
 "Default settings for django-scribbler."
-from __future__ import unicode_literals
-
 import hashlib
 
 from django.conf import settings
@@ -15,7 +13,7 @@ CACHE_PREFIX = 'scribbler'
 
 def default_cache_key(slug, url):
     "Construct a cache key for a given slug/url pair."
-    sha = hashlib.sha1('{0}#{1}'.format(url, slug).encode('ascii'))
+    sha = hashlib.sha1('{0}#{1}'.format(url, slug).encode('utf8'))
     return '{0}:{1}'.format(CACHE_PREFIX, sha.hexdigest())
 
 
