@@ -1,32 +1,42 @@
 "Create/edit forms for scribble content."
-from __future__ import unicode_literals
-
-import sys
-
 from django import forms
-from django.db.models import ObjectDoesNotExist, FieldDoesNotExist
-from django.template import StringOrigin
-from django.template.debug import DebugLexer, DebugParser
-from django.views.debug import ExceptionReporter
-from django.core.urlresolvers import reverse
+from django.core.exceptions import FieldDoesNotExist, ObjectDoesNotExist
+from django.template import Origin, Template
+from django.urls import reverse
+from django.contrib.contenttypes.models import ContentType
+from django.utils.encoding import force_str
 
 from .models import Scribble
 
+
 class ScribbleFormMixin(object):
 
     def clean_content(self):
         content = self.cleaned_data.get('content', '')
         if content:
-            origin = StringOrigin(content)
-            lexer = DebugLexer(content, origin)
+            origin = Origin(content)
+
+            # Try to create a Template
             try:
-                parser = DebugParser(lexer.tokenize())
-                parser.parse()
+                template = Template(template_string=force_str(content), origin=origin)
             except Exception as e:
-                self.exc_info = sys.exc_info()
-                if not hasattr(self.exc_info[1], 'django_template_source'):
-                    self.exc_info[1].django_template_source = origin, (0, 0)
+                # This is an error with creating the template
+                self.exc_info = {
+                    'message': e.args,
+                    'line': e.token.lineno,
+                    'name': origin.name,
+                }
                 raise forms.ValidationError('Invalid Django Template')
+
+            # Template has been created; try to parse
+            try:
+                template.compile_nodelist()
+            except Exception as e:
+                # This is an error with parsing
+                # The data we pass to the views is in e.template_debug
+                e.template_debug = template.get_exception_info(e, e.token)
+                self.exc_info = e.template_debug
+                raise forms.ValidationError('Parsing Error')
         return content
 
 
@@ -44,6 +54,10 @@ class ScribbleForm(forms.ModelForm, ScribbleFormMixin):
     def get_data_prefix(self):
         return self.instance.slug
 
+    def get_preview_url(self):
+        content_type = ContentType.objects.get_for_model(Scribble)
+        return reverse('preview-scribble', args=(content_type.pk,))
+
     def get_save_url(self):
         return self.instance.get_save_url()
 
@@ -71,7 +85,7 @@ class FieldScribbleForm(forms.Form, ScribbleFormMixin):
         self.field_name = field_name
         self.fields['content'].initial = field_value
         try:
-            self.fields['content'].required = not content_type.model_class()._meta.get_field_by_name(field_name)[0].blank
+            self.fields['content'].required = not content_type.model_class()._meta.get_field(field_name).blank
         except FieldDoesNotExist:
             # Error will be caught on form validation
             pass
@@ -94,12 +108,15 @@ class FieldScribbleForm(forms.Form, ScribbleFormMixin):
     def get_data_prefix(self):
         return self.prefix
 
+    def get_preview_url(self):
+        return reverse('preview-scribble', args=(self.content_type.pk,))
+
     def get_save_url(self):
         args=(self.content_type.pk, self.instance_pk, self.field_name)
         return reverse('edit-scribble-field', args=args)
 
     def get_delete_url(self):
-        raise NotImplemented()
+        raise NotImplementedError()
 
     def save(self):
         self.content_type.model_class().objects.filter(pk=self.instance_pk).update(
